#ifndef TaskAttributesModel_h
#define TaskAttributesModel_h

// $Id: TaskAttributesModel.h,v 1.9 2011/11/11 13:29:09 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    TaskAttributesModel.h
\brief   Stores file information for display in lists
\author  Hugo Pereira
\version $Revision: 1.9 $
\date    $Date: 2011/11/11 13:29:09 $
*/

#include "Counter.h"
#include "ListModel.h"
#include "TaskAttributes.h"

//! TaskAttributes model. Stores file information for display in lists
class TaskAttributesModel : public ListModel<TaskAttributes>, public Counter
{

    public:

    //! constructor
    TaskAttributesModel(QObject *parent = 0);

    //! destructor
    virtual ~TaskAttributesModel()
    {}

    //! number of columns
    enum { nColumns_ = 5 };

    //! column type enumeration
    enum ColumnType {
        ICON,
        NAME,
        COMMENTS,
        COMMAND
    };

    //!@name methods reimplemented from base class
    //@{

    // return data for a given index
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    { return nColumns_; }

    //@}

    protected:

    //! sort
    void _sort( int, Qt::SortOrder )
    {}

    private:

    //! icon cache
    typedef std::map<QString, QIcon> IconCache;

    // icon cache
    static IconCache& _icons( void );

    // icon
    static QIcon _icon( const QString& name );

    //! list column names
    static const QString columnTitles_[nColumns_];

};

#endif
