#ifndef _TaskListConfiguration_h_
#define _TaskListConfiguration_h_

// $Id: TaskListConfiguration.h,v 1.10 2011/11/11 13:29:10 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file TaskListConfiguration.h
\brief task list configuration
\author Hugo Pereira
\version $Revision: 1.10 $
\date $Date: 2011/11/11 13:29:10 $
*/

#include "Counter.h"
#include "TaskAttributesModel.h"
#include "TreeView.h"

#include <QtGui/QWidget>
#include <QtGui/QPushButton>

//! task information editor dialog
class TaskListConfiguration: public QWidget, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    TaskListConfiguration(
        QWidget* parent,
        const TaskAttributes::List& task_list = TaskAttributes::List() );

    //! task list
    void setTaskList( const TaskAttributes::List& task_list );

    //! task list
    TaskAttributes::List taskAttributesList( void );

    //! backup task list
    const TaskAttributes::List& backupTaskAttributesList( void )
    { return backupTaskList_; }

    signals:

    //! emmited when the pressed button is called
    void configurationChanged( const TaskAttributes::List& attributes );

    public slots:

    //! apply changes, emit config changed
    void apply( void );

    //! reset
    void cancel( void );

    protected slots:

    //! update buttons
    void _updateButtons( void );

    //! add a task
    void _add( void );

    //! add a separator
    void _addSeparator( void );

    //! edit selected task(s)
    void _edit( void );

    //! remove selected task
    void _remove( void );

    //! move up selected task
    void _up( void );

    //! move down selected task
    void _down( void );

    //! update buttons based on selection
    // void _updateButtons( void );

    private:

    //! list widget
    TreeView& _list( void ) const
    { return *list_; }

    //! attributes backup
    TaskAttributes::List backupTaskList_;

    //! model
    TaskAttributesModel model_;

    //! list of files
    TreeView* list_;

    //! add button
    QPushButton* addButton_;

    //! add separator
    QPushButton* addSeparator_;

    //! edit
    QPushButton* edit_;

    //! remove
    QPushButton* remove_;

    //! move up
    QPushButton* moveUp_;

    //! move down
    QPushButton* moveDown_;

};

#endif
